==> unvanquished-0.28.0.tar.xz: unvanquished-0.28.0/src/engine/null/null_input.cpp <==
/*
===========================================================================

Wolfenstein: Enemy Territory GPL Source Code
Copyright (C) 1999-2010 id Software LLC, a ZeniMax Media company.

This file is part of the Wolfenstein: Enemy Territory GPL Source Code (Wolf ET Source Code).

Wolf ET Source Code is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Wolf ET Source Code is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Wolf ET Source Code.  If not, see <http://www.gnu.org/licenses/>.

In addition, the Wolf: ET Source Code is also subject to certain additional terms. You should have received a copy of these additional terms immediately following the terms and conditions of the GNU General Public License which accompanied the Wolf ET Source Code.  If not, please request a copy in writing from id Software at the address below.

If you have questions concerning this license or the applicable additional terms, you may contact in writing id Software LLC, c/o ZeniMax Media Inc., Suite 120, Rockville, Maryland 20850 USA.

===========================================================================
*/

#include "../qcommon/q_shared.h"
#include "../qcommon/qcommon.h"

void IN_Init( void* windowData )
{
}

void IN_Frame( void )
{
}

void IN_FrameEnd( void )
{
}

void IN_Restart( void )
{
}

void IN_Shutdown( void )
{
}

void Sys_SendKeyEvents( void )
{
}

// TTimo: added for win32 dedicated
void IN_MouseEvent( int mstate )
{
}

void IN_Activate( qboolean active )
{
}

void IN_DropInputsForFrame( void )
{
}

==> unvanquished-0.38.0.tar.xz: unvanquished-0.38.0/src/engine/null/null_input.cpp <==
/*
===========================================================================

Wolfenstein: Enemy Territory GPL Source Code
Copyright (C) 1999-2010 id Software LLC, a ZeniMax Media company.

This file is part of the Wolfenstein: Enemy Territory GPL Source Code (Wolf ET Source Code).

Wolf ET Source Code is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Wolf ET Source Code is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Wolf ET Source Code.  If not, see <http://www.gnu.org/licenses/>.

In addition, the Wolf: ET Source Code is also subject to certain additional terms. You should have received a copy of these additional terms immediately following the terms and conditions of the GNU General Public License which accompanied the Wolf ET Source Code.  If not, please request a copy in writing from id Software at the address below.

If you have questions concerning this license or the applicable additional terms, you may contact in writing id Software LLC, c/o ZeniMax Media Inc., Suite 120, Rockville, Maryland 20850 USA.

===========================================================================
*/

#include "qcommon/q_shared.h"
#include "qcommon/qcommon.h"

void IN_Init( void* windowData )
{
}

void IN_Frame( void )
{
}

void IN_FrameEnd( void )
{
}

void IN_Restart( void )
{
}

void IN_Shutdown( void )
{
}

void Sys_SendKeyEvents( void )
{
}

// TTimo: added for win32 dedicated
void IN_MouseEvent( int mstate )
{
}

void IN_Activate( qboolean active )
{
}

void IN_DropInputsForFrame( void )
{
}

bool IN_IsNumLockDown()
{
    return false;
}
